pub struct CustomReactiveNode<Change, Context, Action, WatchFn, ReactFn>where
Change: Send + Sync + 'static,
Context: Send + Sync + 'static,
Action: ActionType + Send + Sync + 'static + Debug,
WatchFn: Fn() -> Result<Box<dyn Stream<Item = Change> + Send + Unpin>, FloxideError> + Send + Sync + 'static,
ReactFn: Fn(Change, &mut Context) -> Result<Action, FloxideError> + Send + Sync + 'static,{ /* private fields */ }Expand description
A custom reactive node that uses a provided closure to create the watch stream and react to changes.
Implementations
Sourceimpl<Change, Context, Action, WatchFn, ReactFn> CustomReactiveNode<Change, Context, Action, WatchFn, ReactFn>where
Change: Send + Sync + 'static,
Context: Send + Sync + 'static,
Action: ActionType + Send + Sync + 'static + Debug,
WatchFn: Fn() -> Result<Box<dyn Stream<Item = Change> + Send + Unpin>, FloxideError> + Send + Sync + 'static,
ReactFn: Fn(Change, &mut Context) -> Result<Action, FloxideError> + Send + Sync + 'static,
impl<Change, Context, Action, WatchFn, ReactFn> CustomReactiveNode<Change, Context, Action, WatchFn, ReactFn>where
Change: Send + Sync + 'static,
Context: Send + Sync + 'static,
Action: ActionType + Send + Sync + 'static + Debug,
WatchFn: Fn() -> Result<Box<dyn Stream<Item = Change> + Send + Unpin>, FloxideError> + Send + Sync + 'static,
ReactFn: Fn(Change, &mut Context) -> Result<Action, FloxideError> + Send + Sync + 'static,