FileWatcherNode

Struct FileWatcherNode 

pub struct FileWatcherNode<Context, Action>
where Context: Send + Sync + 'static, Action: ActionType + Send + Sync + 'static + Debug,
{ /* private fields */ }
A node that watches a file for changes

Implementations

Source

impl<Context, Action> FileWatcherNode<Context, Action>
where Context: Send + Sync + 'static, Action: ActionType + Send + Sync + 'static + Debug,

pub fn new<P: Into<String>>(file_path: P) -> Self

Create a new file watcher node

pub fn with_id<P: Into<String>>(file_path: P) -> Self

Create a new file watcher node with a specified ID

pub fn with_poll_interval(self, interval: Duration) -> Self

Set the poll interval for the file watcher

pub fn with_change_handler<F, Fut>(self, handler: F) -> Self
where F: Fn(FileChange, &mut Context) -> Fut + Send + Sync + 'static, Fut: Future<Output = Result<Action, FloxideError>> + Send + 'static,

Set the change handler for the file watcher node