pub struct FileWatcherNode<Context, Action>{ /* private fields */ }Expand description
A node that watches a file for changes
Implementations
Sourceimpl<Context, Action> FileWatcherNode<Context, Action>
impl<Context, Action> FileWatcherNode<Context, Action>
Sourcepub fn with_id<P: Into<String>>(file_path: P) -> Self
pub fn with_id<P: Into<String>>(file_path: P) -> Self
Create a new file watcher node with a specified ID
Sourcepub fn with_poll_interval(self, interval: Duration) -> Self
pub fn with_poll_interval(self, interval: Duration) -> Self
Set the poll interval for the file watcher
Sourcepub fn with_change_handler<F, Fut>(self, handler: F) -> Selfwhere
F: Fn(FileChange, &mut Context) -> Fut + Send + Sync + 'static,
Fut: Future<Output = Result<Action, FloxideError>> + Send + 'static,
pub fn with_change_handler<F, Fut>(self, handler: F) -> Selfwhere
F: Fn(FileChange, &mut Context) -> Fut + Send + Sync + 'static,
Fut: Future<Output = Result<Action, FloxideError>> + Send + 'static,
Set the change handler for the file watcher node